#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter
version:              1.7.1
visibility:           public
id:                   prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW
key:                  prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW
license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:
    Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky, Simon Jakobi

homepage:             http://github.com/quchen/prettyprinter
synopsis:
    A modern, easy to use, well-documented, extensible pretty-printer.

description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md

category:             User Interfaces, Text
abi:                  22749b85157ab0d95afccb6f8797b654
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Debug
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util Prettyprinter Prettyprinter.Internal
    Prettyprinter.Internal.Debug Prettyprinter.Internal.Type
    Prettyprinter.Render.String Prettyprinter.Render.Text
    Prettyprinter.Render.Tutorials.StackMachineTutorial
    Prettyprinter.Render.Tutorials.TreeRenderingTutorial
    Prettyprinter.Render.Util.Panic
    Prettyprinter.Render.Util.SimpleDocTree
    Prettyprinter.Render.Util.StackMachine Prettyprinter.Symbols.Ascii
    Prettyprinter.Symbols.Unicode Prettyprinter.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/prettyprinter-1.7.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/prettyprinter-1.7.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/prettyprinter-1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter
hs-libraries:         HSprettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

